@@ -2,38 +2,37 @@
 enhance your app with context help, user onboarding, product tours, walkthroughs and tutorials
 ==============================================================================================
 
-This ae namespace portion integrates context-sensitive help, user onboarding, product tours, walkthroughs and tutorials
+this ae namespace portion integrates context-sensitive help, user onboarding, product tours, walkthroughs and tutorials
 into your kivy app.
 
-The generic class :class:`Tooltip` of this portion displays text blocks that are automatically positioned next to any
+the generic class :class:`Tooltip` of this portion displays text blocks that are automatically positioned next to any
 widget to providing e.g. i18n context help texts or app tour/onboarding info.
 
 :class:`ModalBehavior` is another generic mix-in class that provides modal behavior to any container widget.
 
-The mixin class :class:`HelpBehavior` provided by this namespace portion is extending and preparing any Kivy widget for
-to show an individual help text for it. The widget :class:`HelpToggler` is a toggle button to switch the help mode
-on and off.
+the mixin class :class:`HelpBehavior` provided by this namespace portion extends and prepares any Kivy widget to show an
+individual help text for it. the widget :class:`HelpToggler` is a toggle button to switch the help mode on and off.
 
-The other classes of this portion are used to overlay or augment the app’s user interface with product tours, tutorials,
+the other classes of this portion are used to overlay or augment the app’s user interface with product tours, tutorials,
 walkthroughs and user onboarding/welcome features.
 
-The :class:`AnimatedTourMixin` can be mixed-into a tour class that inherits from :class:`~ae.gui_help.TourBase` to
+the :class:`AnimatedTourMixin` can be mixed-into a tour class that inherits from :class:`~ae.gui_help.TourBase` to
 extend it with animation and glsl shader features.
 
-The class :class:`AnimatedOnboardingTour` is providing an app onboarding tour that covers the core features and can be
+the class :class:`AnimatedOnboardingTour` is providing an app onboarding tour that covers the core features and can be
 easily extended with app-specific tour pages.
 
-Finally, the class :class:`TourOverlay` is implementing a overlay layout widget to display the animations, shaders,
+finally, the class :class:`TourOverlay` is implementing a overlay layout widget to display the animations, shaders,
 tour page texts, tooltip text and the navigation buttons of an active/running app tour.
 
 
 mixing-in modal behavior
-------------------------
+========================
 
-To convert a container widget into a modal dialog, add the :class:`ModalBehavior` mix-in class, provided by this ae
+to convert a container widget into a modal dialog, add the :class:`ModalBehavior` mix-in class, provided by this ae
 namespace portion.
 
-The following code snippet demonstrates a typical implementation::
+the following code snippet demonstrates a typical implementation::
 
     class MyContainer(ModalBehavior, BoxLayout):
         def __init__(self, **kwargs):
@@ -46,10 +45,10 @@ The following code snippet demonstrates a typical implementation::
             self.deactivate_modal()
 
 
-To activate the modal mode call the method :meth:`~ModalBehavior.activate_modal`. The modal mode can be deactivated by
+to activate the modal mode call the method :meth:`~ModalBehavior.activate_modal`. the modal mode can be deactivated by
 calling the :meth:`~ModalBehavior.deactivate_modal` method.
 
-All touch, mouse and keyboard user interactions will be consumed or filtered after activating the modal mode. Therefore
+all touch, mouse and keyboard user interactions will be consumed or filtered after activating the modal mode. therefore
 it is recommended to also visually change the GUI while in the modal mode, which has to be implemented by the mixing-in
 container widget.
 
@@ -59,10 +58,10 @@ container widget.
 
 
 generic widget to display help and tour texts
----------------------------------------------
+=============================================
 
-the tooltip class :class:`Tooltip` is targeting any widget by pointing with an arrow to it. The position and size of
-this widget gets automatically calculated from the targeted widget position and size and the tooltip text size. And if
+the tooltip class :class:`Tooltip` is targeting any widget by pointing with an arrow to it. the position and size of
+this widget gets automatically calculated from the targeted widget position and size and the tooltip text size. and if
 the screen/window size is not big enough then the tooltip texts get scrollable.
 
 .. hint::
@@ -71,9 +70,9 @@ the screen/window size is not big enough then the tooltip texts get scrollable.
 
 
 help behaviour mixin
---------------------
+====================
 
-To show a i18n translatable help text for a Kivy widget create either a sub-class of the widget. The following example
+to show a i18n translatable help text for a Kivy widget create either a sub-class of the widget. the following example
 allows to attach a help text to a Kivy :class:`~kivy.uix.button.Button`::
 
     from kivy.uix.button import Button
@@ -82,37 +81,48 @@ allows to attach a help text to a Kivy :class:`~kivy.uix.button.Button`::
     class ButtonWithHelpText(HelpBehavior, Button):
         ...
 
-Alternatively you can archive this via the definition of a new kv-lang rule, like shown underneath::
+alternatively you can archive this via the definition of a new kv-lang rule, like shown underneath::
 
     <ButtonWithHelpText@HelpBehavior+Button>
 
-
 .. note::
-    To automatically lock and mark the widget you want to add help texts for, this mixin class has to be specified
+    to automatically lock and mark the widget you want to add help texts for, this mixin class has to be specified
     as the first inheriting class in the class or rule declaration.
 
-
 help activation and de-activation
 ---------------------------------
 
-Use the widget :class:`HelpToggler` provided by this namespace portion in your app to toggle the active state of the
+use the widget :class:`HelpToggler` provided by this namespace portion in your app to toggle the active state of the
 help mode.
 
 .. hint::
-    The :class:`HelpToggler` is using the low-level touch events to prevent the dispatch of the Kivy events `on_press`,
+    the :class:`HelpToggler` is using the low-level touch events to prevent the dispatch of the Kivy events `on_press`,
     `on_release` and `on_dismiss` to allow to show help texts for opened dropdowns and popups.
 
 
-kivy_help portion dependencies
-------------------------------
+animated app tours
+==================
 
-Although this portion depends only on the `Kivy framework <kivy>`_ and the ae namespace portions :mod:`ae.gui_app`,
+the mix-in class :class:`AnimatedTourMixin` extends any tour class inherited from :class:`~ae.gui_help.TourBase` with
+animations and glsl shaders.
+
+the class :class:`AnimatedOnboardingTour` uses :class:`AnimatedTourMixin` to extend the generic app onboarding tour
+class :class:`~ae.gui_help.OnboardingTour` with animations.
+
+to integrate a more app-specific onboarding tour into your app, simply declare a class with a name composed by the name
+of your app (:attr:`~ae.gui_app.MainAppBase.app_name`) in camel-case, followed by the suffix `'OnboardingTour'`.
+
+
+kivy_help portion dependencies
+==============================
+
+although this portion depends only on the `Kivy framework <kivy>`_ and the ae namespace portions :mod:`ae.gui_app`,
 :mod:`ae.gui_help` and :mod:`ae.kivy_relief_canvas`, it is recommended also include and use the portion
 :mod:`ae.kivy_app` to provide context-help-aware widgets.
 
-This namespace portion is a requirement of the :mod:`ae.kivy_app` module and is tight coupled to it. So when you also
+this namespace portion is a requirement of the :mod:`ae.kivy_app` module and is tight coupled to it. so when you also
 include and use the :mod:`ae.kivy_app` for your app, then you only need to specify the :mod:`ae.kivy_app` portion in the
-`requirements.txt` files (of the `pip` package installation tool) to automatically integrate also this module. Only for
+`requirements.txt` files (of the `pip` package installation tool) to automatically integrate also this module. only for
 mobile apps built with buildozer you need also to explicitly add this :mod:`ae.kivy_help` portion to the requirements
 list in your `buildozer.spec` file.
 """
@@ -121,7 +131,8 @@ import traceback
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 
-from kivy.animation import Animation                                                                    # type: ignore
+# noinspection PyProtectedMember
+from kivy.animation import Animation, CompoundAnimation                                                 # type: ignore
 from kivy.app import App                                                                                # type: ignore
 from kivy.clock import Clock                                                                            # type: ignore
 from kivy.core.window import Window                                                                     # type: ignore
@@ -129,21 +140,24 @@ from kivy.input import MotionEvent
 from kivy.lang import Builder                                                                           # type: ignore
 # pylint: disable=no-name-in-module
 from kivy.metrics import sp                                                                             # type: ignore
-from kivy.properties import (  # type: ignore
+from kivy.properties import (                                                                           # type: ignore
     BooleanProperty, DictProperty, ListProperty, NumericProperty, ObjectProperty, StringProperty)
+from kivy.uix.behaviors import ButtonBehavior, ToggleButtonBehavior                                     # type: ignore
 from kivy.uix.floatlayout import FloatLayout                                                            # type: ignore
 from kivy.uix.image import Image                                                                        # type: ignore
 from kivy.uix.scrollview import ScrollView                                                              # type: ignore
 from kivy.uix.textinput import TextInput                                                                # type: ignore
 from kivy.uix.widget import Widget                                                                      # type: ignore
 
+from ae.base import snake_to_camel                                                                      # type: ignore
 from ae.inspector import try_eval                                                                       # type: ignore
-from ae.gui_help import anchor_points, help_id_tour_class, HelpAppBase, OnboardingTour, TourBase        # type: ignore
+from ae.gui_help import (                                                                               # type: ignore
+    anchor_points, help_id_tour_class, HelpAppBase, OnboardingTour, TourBase, REGISTERED_TOURS)
 from ae.kivy_glsl import ShaderIdType, ShadersMixin                                                     # type: ignore
 from ae.kivy_relief_canvas import ReliefCanvas                                                          # type: ignore
 
 
-__version__ = '0.2.28'
+__version__ = '0.2.29'
 
 
 # load/declared help/tour widgets, based-on Kivy core widgets (without any features from ae.kivy_app/widgets.kv)
@@ -287,9 +301,8 @@ class HelpBehavior:
         if main_app.help_activator.collide_point(*touch.pos):
             return False        # allow help activator button to process this touch down event
 
-        if self.help_lock and self.collide_point(*touch.pos):   # main_app.help_layout is not None
-            if main_app.help_display(self.help_id, self.help_vars):
-                return True
+        if self.help_lock and self.collide_point(*touch.pos) and main_app.help_display(self.help_id, self.help_vars):
+            return True         # main_app.help_layout is not None
 
         return super().on_touch_down(touch)                 # type: ignore # pylint: disable=no-member # false positive
 
@@ -390,6 +403,53 @@ class HelpToggler(ReliefCanvas, Image):
         return False
 
 
+PageAnimationType = Tuple[str, Union[Animation, str]]
+""" tuple of a widget id string and an :class:`~kivy.animation.Animation` instance/evaluation-expression.
+
+    if the first character of the widget id is a `@` then the :attr:`~kivy.animation.Animation.repeat` attribute of
+    the :class:`~kivy.animation.Animation` instance will be set to True. the rest of the widget id string specifies
+    the widget to be animated which is either:
+
+    * one of the widgets of the :class:`TourOverlay` layout class, identified by the on of the following strings:
+      `'next_but'`, `'page_lbl'`, `'tap_pointer'`, `'prev_but'`, `'title_lbl'`, `'tooltip'`, `'tour_page_texts'`.
+    * the explained widget if an empty string is given.
+    * the :class:`TourOverlay` layout class instance for any other string (e.g. `'layout'` or `'overlay'`).
+
+    alternative to an animation instance, a evaluation string can be specified. these evaluations allow to use the
+    following globals: :class:`~kivy.animation.Animation` (also abbreviated as `A`), :class:`~kivy.clock.Clock`,
+    :attr:`~ae.gui_help.TourBase.layout`, :attr:`~kivy.metrics.sp`, :class:`~kivy.core.window.Window` and a
+    reference to the instance of this app tour via `tour`.
+"""
+
+PageAnimationsType = Tuple[PageAnimationType, ...]  #: tuple of :data:`PageAnimationType` items
+
+WidgetValues = Dict[str, Union[list, tuple, dict, float]]
+""" a key of this dict specifies the name, the dict value the value of a widget property/attribute. """
+
+
+def animated_widget_values(wid: Widget, ani: Union[Animation, CompoundAnimation]) -> WidgetValues:
+    """ determine from a widget the attribute/property values animated/changed by an animation.
+
+    :param wid:                 widget of which the animation property values will get retrieved.
+    :param ani:                 :class:`~kivy.animation.Animation`/:class:`kivy.animation.CompoundAnimation` instance.
+    :return:                    dict with widget property names and values.
+    """
+    wid_values = dict()
+    for key in ani.animated_properties.keys():
+        wid_values[key] = getattr(wid, key)
+    return wid_values
+
+
+def restore_widget_values(wid: Widget, values: WidgetValues):
+    """ restore property values of a widget.
+
+    :param wid:                 widget of which the animation property values will get restored.
+    :param values:              attribute/property values to restore on the widget.
+    """
+    for attr, value in values.items():
+        setattr(wid, attr, value)
+
+
 class AnimatedTourMixin:        # (TourBase):
     """ tour class mixin to add individual shaders to the tour layout and their children widgets. """
     # abstracts
@@ -397,89 +457,120 @@ class AnimatedTourMixin:        # (TourBase):
     main_app: Any
     page_ids: List[str]
     page_idx: int
+    setup_texts: Callable
 
     def __init__(self, main_app: 'HelpAppBase') -> None:
         super().__init__(main_app)                                          # type: ignore # pylint: disable=no-member
 
-        self._added_animations: List[Tuple[Widget, Animation]] = list()
+        self._added_animations: List[Tuple[Widget, Animation, WidgetValues]] = list()
         self._added_shaders: List[Tuple[Widget, ShaderIdType]] = list()
 
-        self.pages_animations: Dict[Optional[str], Tuple[Tuple[str, Union[Animation, str]], ...]] = dict()
-        """ statically declarable class attribute dict of compound animation instances of the pages of this tour.
+        self.pages_animations: Dict[Optional[str], PageAnimationsType] = dict()
+        """ dict of compound animation instances of the pages of this tour.
 
         the key of this dict is the page id or None (for animations available in all pages of this tour).
-        the value of this dict is a tuple of tuples of widget id and animation instances.
-
-        if the first character of the widget id is a `@` then the :attr:`~kivy.animation.Animation.repeat` attribute of
-        the :class:`~kivy.animation.Animation` class will be set to True. the rest of the widget id string specifies the
-        widget to be animated which is either:
-
-        * one of the widgets of the :class:`TourOverlay` layout class, like `tooltip`, `tour_page_texts`, `title_lbl`,
-          `page_lbl`, `prev_but` or `next_but`.
-        * the explained widget if an empty string is given.
-        * the :class:`TourOverlay` layout class instance for any other string.
+        each value of this dict is of the type :data:`PageAnimationsType`.
         """
 
         self.pages_shaders: Dict[Optional[str], Tuple[Tuple[str, ShaderIdType], ...]] = dict()
-        """ statically declarable class attribute dict of widget shaders for the pages of this tour.
+        """ dict of widget shaders for the pages of this tour.
 
         the key of this dict is the page id or None (for shaders available in all pages of this tour).
-        the value of this dict is a tuple of tuples of widget id and add_shader()-kwargs.
+        each value of this dict is a tuple of tuples of widget id and add_shader()-kwargs.
 
         the widget id string specifies the widget to which a shader will be added, which is either:
 
-        * one of the widgets of the :class:`TourOverlay` layout class, like `tooltip`, `tour_page_texts`, `title_lbl`,
-          `page_lbl`, `prev_but` or `next_but`.
+        * one of the widgets of the :class:`TourOverlay` layout class, identified by the on of the following strings:
+          `'next_but'`, `'page_lbl'`, `'tap_pointer'`, `'prev_but'`, `'title_lbl'`, `'tooltip'`, `'tour_page_texts'`.
         * the explained widget if an empty string is given.
-        * the :class:`TourOverlay` layout class instance for any other string.
+        * the :class:`TourOverlay` layout class instance for any other string (e.g. `'layout'` or `'overlay'`).
 
-        the add_shader()-kwargs dict will directly be passed to the :meth:`~ae.kivy_glsl.ShadersMixin.add_shader`
-        method.
+        before the add_shader()-kwargs dict will be passed to the :meth:`~ae.kivy_glsl.ShadersMixin.add_shader` method,
+        all their non-string values, specifying as strings, will be evaluated/converted automatically. the evaluation
+        provides the following globals: :attr:`~ae.gui_help.TourBase.layout`, :attr:`~kivy.metrics.sp`,
+        :class:`~kivy.clock.Clock`, :class:`~kivy.core.window.Window` and the `tour` instance.
         """
 
-    def _evaluated_shader_kwargs(self, shader_kwargs: dict) -> dict:
-        tour_shader_kwargs = deepcopy(shader_kwargs)
-        glo_vars = self.main_app.global_variables(layout=self.layout, sp=sp, tour=self, Clock=Clock, Window=Window)
-        for key, arg in tour_shader_kwargs.items():
-            if isinstance(arg, str) and key not in ('add_to', 'render_shape', 'shader_code', 'shader_file'):
-                tour_shader_kwargs[key] = try_eval(arg, glo_vars=glo_vars)
-        return tour_shader_kwargs
+        self.switch_next_animations: Dict[Optional[str], PageAnimationsType] = dict()
+        """ dict of compound animation instances for the next page switch transition of the pages of this tour.
 
-    def setup_animations(self):
-        """ setup shaders specified in class attribute :attr:`~AnimatedTourMixin.pages_shaders`. """
+        the key of this dict is the page id or None (for animations available in all pages of this tour).
+        each value of this dict is of the type :data:`PageAnimationsType`.
+        """
+
+    def _add_animations(self, animations: PageAnimationsType):
+        """ add animations to the tour page currently displayed in the tour layout/overlay.
+
+        :param animations:      tuple of tuples of widget id and animation instance/evaluation-string.
+        :return:                length of the longest animation added (in seconds).
+        """
+        max_len = 0.0
         layout = self.layout
-        page_id = self.page_ids[self.page_idx]
-
-        pages_shaders = self.pages_shaders.get(None, ()) + self.pages_shaders.get(page_id, ())
         added = list()
-        for wid_id, shader_kwargs in pages_shaders:
-            wid = layout.ids.get(wid_id, layout) if wid_id else self.layout.explained_widget
-            added.append((wid, wid.add_shader(**self._evaluated_shader_kwargs(shader_kwargs))))
-        self._added_shaders = added
-
-        pages_animations = self.pages_animations.get(None, ()) + self.pages_animations.get(page_id, ())
-        added = list()
-        for wid_id, anim in pages_animations:
+        for wid_id, anim in animations:
             if isinstance(anim, str):
-                glo_vars = self.main_app.global_variables(layout=self.layout, sp=sp, tour=self,
+                glo_vars = self.main_app.global_variables(layout=layout, sp=sp, tour=self,
                                                           A=Animation, Animation=Animation, Clock=Clock, Window=Window)
                 anim = try_eval(anim, glo_vars=glo_vars)
-            if wid_id[0] == '@':
+            if wid_id[0:1] == '@':
                 wid_id = wid_id[1:]
                 anim.repeat = True
-            wid = layout.ids.get(wid_id, layout) if wid_id else self.layout.explained_widget
+            wid = layout.ids.get(wid_id, layout) if wid_id else layout.explained_widget
+            start_values = animated_widget_values(wid, anim)
             anim.start(wid)
-            added.append((wid, anim))
-        self._added_animations = added
+            added.append((wid, anim, start_values))
+
+            if anim.duration > max_len:
+                max_len = anim.duration
+
+        self._added_animations.extend(added)
+
+        return max_len
+
+    def next_page(self):
+        """ overridden to add demo animations before/on switch to the next tour page. """
+        page_id = self.page_ids[self.page_idx]
+        next_animations = self.switch_next_animations.get(None, ()) + self.switch_next_animations.get(page_id, ())
+        anim_length = self._add_animations(next_animations)
+        if anim_length:
+            # noinspection PyUnresolvedReferences
+            self.main_app.call_method_delayed(anim_length + 0.123, super().next_page)       # pylint: disable=no-member
+        else:
+            # noinspection PyUnresolvedReferences
+            super().next_page()                                                             # pylint: disable=no-member
+
+    def setup_page_shaders_and_animations(self):
+        """ setup shaders and animations of the current page.
+
+        specified in :attr:`~AnimatedTourMixin.pages_shaders` and :attr:`~AnimatedTourMixin.pages_animations`.
+        """
+        def _evaluated_shader_kwargs() -> dict:
+            tour_shader_kwargs = deepcopy(shader_kwargs)
+            glo_vars = self.main_app.global_variables(layout=layout, sp=sp, tour=self, Clock=Clock, Window=Window)
+            for key, arg in tour_shader_kwargs.items():
+                if isinstance(arg, str) and key not in ('add_to', 'render_shape', 'shader_code', 'shader_file'):
+                    tour_shader_kwargs[key] = try_eval(arg, glo_vars=glo_vars)
+            return tour_shader_kwargs
+
+        page_id = self.page_ids[self.page_idx]
+        page_shaders = self.pages_shaders.get(None, ()) + self.pages_shaders.get(page_id, ())
+        layout = self.layout
+        added = list()
+        for wid_id, shader_kwargs in page_shaders:
+            wid = layout.ids.get(wid_id, layout) if wid_id else layout.explained_widget
+            added.append((wid, wid.add_shader(**_evaluated_shader_kwargs())))
+        self._added_shaders = added
+
+        self._add_animations(self.pages_animations.get(None, ()) + self.pages_animations.get(page_id, ()))
 
     def setup_layout(self):
         """ overridden to setup animations and shaders of the current tour page. """
         # noinspection PyUnresolvedReferences
         super().setup_layout()                                                              # pylint: disable=no-member
-        self.setup_animations()
+        self.setup_page_shaders_and_animations()
 
     def simulate_text_input(self, text_input: TextInput, text_to_delay: str,
-                            text_to_insert: str = "", deltas: Tuple[float, ...] = (0.9, 0.6, 0.3)):
+                            text_to_insert: str = "", deltas: Tuple[float, ...] = (1.8, 0.6, 0.3)):
         """ simulate the typing of texts by a user entered into an explained TextInput widget of a tour page.
 
         :param text_input:      text input widget, either of type :class:`~kivy.textinput.TextInput` or
@@ -487,38 +578,84 @@ class AnimatedTourMixin:        # (TourBase):
         :param text_to_delay:   text string to be inserted delayed by the seconds specified in deltas[0].
         :param text_to_insert:  text string to be inserted directly into the passed text input widget.
         :param deltas:          delay deltas in seconds between each character to simulate text inputted by a user.
+                                first delta default is a bit higher to finish navigation button y-pos-animation.
         """
         if text_input.get_root_window():
-            if text_to_insert:
-                if text_input.interesting_keys.get(ord(text_to_insert), None) == 'backspace':
+            for char_to_insert in text_to_insert:
+                if text_input.interesting_keys.get(ord(char_to_insert), None) == 'backspace':   # chr(8)
                     text_input.do_backspace()
                 else:
-                    text_input.insert_text(text_to_insert)
+                    text_input.insert_text(char_to_insert)
 
             if text_to_delay:
                 next_delay = deltas[0]
                 self.main_app.call_method_delayed(next_delay, self.simulate_text_input, text_input, text_to_delay[1:],
                                                   text_to_insert=text_to_delay[0], deltas=deltas[1:] + (next_delay, ))
 
-    def teardown_animations(self):
-        """ teardown shaders added by :meth:`~AnimatedTourMixin.setup_animations` method for current tour page. """
-        for wid, anim in reversed(self._added_animations):
+    def tap_animation(self, wid_id: str = '', position_delay: float = 2.34,
+                      press_delay: float = 0.69, release_delay: float = 0.39) -> PageAnimationType:
+        """ create an compound animation instance simulating a user touch/tap on the widget with the passed widget id.
+
+        :param wid_id:          specifies the widget to be tap simulated: either a widget id string (first item of the
+                                :data:`PageAnimationType` tuple), or (if prefixed with a column character) tap/focus/
+                                state id of a widget, or an empty string (specifies the currently explained widget).
+        :param position_delay:  time in seconds to move the pointer from the next button to the widget.
+        :param press_delay:     time in seconds of the button press simulation animation.
+        :param release_delay:   time in seconds of the button release simulation animation.
+        :return:                compound animation instance simulating a tap.
+
+        .. note:: use as animation evaluation expression, to get the widget values on setup-time of the page (not tour).
+        """
+        layout = self.layout
+        if wid_id[0:1] == ':':
+            tap_wid = self.main_app.widget_by_flow_id(wid_id[1:])
+        else:
+            tap_wid = layout.ids.get(wid_id, layout) if wid_id else layout.explained_widget
+        tap_wid_x, tap_wid_y = tap_wid.to_window(*tap_wid.center)
+        nxt_wid = layout.ids.next_but
+        poi_wid = layout.ids.tap_pointer
+        poi_width, poi_height = poi_wid.size
+        poi_x = tap_wid_x - poi_width * 13.0 / 30.0    # - tap_pointer.png index finger x position offset
+        poi_y = tap_wid_y - poi_height * 29.0 / 30.0
+
+        poi_wid.center = nxt_wid.center
+        press_ani = Animation(x=poi_x + poi_width * 0.156, y=poi_y + poi_height * 0.153,
+                              width=poi_width * 0.69, height=poi_height * 0.69, d=press_delay, t='out_sine')
+        ani = Animation(x=poi_x, y=poi_y, opacity=1.0, d=position_delay, t='in_sine') \
+            + press_ani \
+            + Animation(x=poi_x, y=poi_y, width=poi_width, height=poi_height, opacity=0.39, d=release_delay - 0.03)
+
+        if isinstance(tap_wid, ButtonBehavior):
+            def _touched_anim():
+                wid_state = tap_wid.state
+                tap_wid.state = 'normal' if wid_state == 'down' else 'down'
+                if not isinstance(tap_wid, ToggleButtonBehavior):
+                    self.main_app.call_method_delayed(
+                        release_delay, lambda *_args: (setattr(tap_wid, 'state', wid_state), self.setup_texts()))
+            press_ani.bind(on_complete=lambda *_args: (_touched_anim(), self.setup_texts()))
+
+        return ani
+
+    def teardown_shaders_and_animations(self):
+        """ teardown all added shaders and animations of current tour page (including switch next page animations). """
+        for wid, anim, start_values in reversed(self._added_animations):
             anim.stop(wid)
+            restore_widget_values(wid, start_values)
         self._added_animations = list()
+
         for wid, shader_id in reversed(self._added_shaders):
             wid.del_shader(shader_id)
         self._added_shaders = list()
 
     def teardown_app_flow(self):
         """ overridden to teardown the animations of the current/last-shown tour page. """
-        self.teardown_animations()
+        self.teardown_shaders_and_animations()
         # noinspection PyUnresolvedReferences
         super().teardown_app_flow()                                                         # pylint: disable=no-member
 
 
 class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
-    """ onboarding tour, extended with glsl shaders.
-    """
+    """ onboarding tour, extended with animations and glsl shaders. """
     def __init__(self, main_app: 'HelpAppBase') -> None:
         super().__init__(main_app)
 
@@ -545,7 +682,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
 
         self.pages_shaders.update({
             '': (
-                ('root', dict(
+                ('layout', dict(
                     alpha="lambda: 0.39 * layout.ani_value",
                     center_pos="lambda: list(map(float, layout.ids.next_but.center))",
                     shader_code="=plunge_waves",
@@ -561,7 +698,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                 )),
             ),
             'page_switching': (
-                ('root', dict(
+                ('layout', dict(
                     alpha="lambda: 0.39 * layout.ani_value",
                     center_pos="lambda: list(map(float, layout.ids.prev_but.center))",
                     shader_code="=plunge_waves",
@@ -674,7 +811,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
         elif page_id == 'layout_font_size':
             self._bound = self._added_animations[-1][1].fbind('on_progress', lambda *_args: self.setup_texts())
 
-    def teardown_animations(self):
+    def teardown_shaders_and_animations(self):
         """ overridden to unbind setup_texts() on leaving the responsible_layout tour page. """
         if self._bound:
             page_id = self.page_ids[self.page_idx]
@@ -685,7 +822,7 @@ class AnimatedOnboardingTour(AnimatedTourMixin, OnboardingTour):
                 self._added_animations[-1][1].unbind_uid('on_progress', self._bound)
             self._bound = None
 
-        super().teardown_animations()
+        super().teardown_shaders_and_animations()
 
 
 class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
@@ -736,9 +873,6 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         self.main_app = main_app
         main_app.vpo("TourOverlay.__init__")
 
-        if main_app.onboarding_tour_class is OnboardingTour:
-            main_app.onboarding_tour_class = AnimatedOnboardingTour
-
         self._tooltip_animation = None
         self.auto_dismiss = False
         self.explained_widget = main_app.help_activator             # assign dummy init widget to prevent None errors
@@ -787,8 +921,10 @@ class TourOverlay(ModalBehavior, ShadersMixin, FloatLayout):
         :return:                True if tour exists and got started.
         """
         main_app = self.main_app
-        if tour_cls is None:
-            tour_cls = help_id_tour_class(main_app.displayed_help_id) or main_app.onboarding_tour_class
+        if not tour_cls:
+            tour_cls = help_id_tour_class(main_app.displayed_help_id) \
+                or REGISTERED_TOURS.get(snake_to_camel(main_app.app_name) + 'OnboardingTour') \
+                or AnimatedOnboardingTour
         main_app.vpo(f"TourOverlay.start_tour tour_cls={tour_cls.__name__}")
 
         try:
